// PART OF THE MACHINE SIMULATION. DO NOT CHANGE.

package nachos.machine;

/**
 * A file system that allows the user to create, open, and delete files.
 */
public interface FileSystem {
    /**
     * Atomically open a file, optionally truncating it. If the file does not
     * already exist and <tt>truncate</tt> is <tt>false</tt>, returns
     * <tt>null</tt>. If the file does not already exist and <tt>truncate</tt>
     * is <tt>true</tt>, creates the file with zero length. If the file already
     * exists and <tt>truncate</tt> is <tt>false</tt>, opens the file without
     * changing it in any way. If the file already exists and <tt>truncate</tt>
     * is <tt>true</tt>, truncates the file to zero length and then opens it.
     *
     * @param	name		the name of the file to open.
     * @param	truncate	<tt>true</tt> to create the file if it does not
     *				already exist, or to truncate it to zero length
     *				if it does already exist.
     * @return	an <tt>OpenFile</tt> representing a new instance of the opened
     *		file, or <tt>null</tt> if the file could not be opened.
     */
    public OpenFile open(String name, boolean create);

    /**
     * Atomically remove an existing file. After a file is removed, it cannot
     * be opened until it is created again with <tt>open</tt>. If the file is
     * already open, it is up to the implementation to decide whether the file
     * can still be accessed or if it is deleted immediately.
     *
     * @param	name	the name of the file to remove.
     * @return	<tt>true</tt> if the file was successfully removed.
     */
    public boolean remove(String name);
}
